@@ -1,16 +1,3 @@
-def resolve_import_path_and_get_logger():
-    # ruff: noqa: E402
-    import logging
-    import sys
-
-    if __name__ == "__main__" and "." not in sys.path:
-        sys.path.append(".")
-
-    logger = logging.getLogger(__name__)
-    return logger
-
-
-logger = resolve_import_path_and_get_logger()
 import re
 import sys
 from pathlib import Path
@@ -493,5 +480,9 @@ Remember to follow all instructions in the role prompt, especially regarding HTM
     print("\n--- Presentation Generation Complete! ---")
 
 
-if __name__ == "__main__":
+def main() -> None:
     MakePptArguments().run()
+
+
+if __name__ == "__main__":
+    main()
